"use strict";(self.webpackChunkhome_assistant_frontend=self.webpackChunkhome_assistant_frontend||[]).push([[71250],{23682:(e,t,r)=>{function n(e,t){if(t.length<e)throw new TypeError(e+" argument"+(e>1?"s":"")+" required, but only "+t.length+" present")}r.d(t,{Z:()=>n})},90394:(e,t,r)=>{function n(e){if(null===e||!0===e||!1===e)return NaN;var t=Number(e);return isNaN(t)?t:t<0?Math.ceil(t):Math.floor(t)}r.d(t,{Z:()=>n})},79021:(e,t,r)=>{r.d(t,{Z:()=>s});var n=r(90394),a=r(34327),u=r(23682);function s(e,t){(0,u.Z)(2,arguments);var r=(0,a.Z)(e),s=(0,n.Z)(t);return isNaN(s)?new Date(NaN):s?(r.setDate(r.getDate()+s),r):r}},59699:(e,t,r)=>{r.d(t,{Z:()=>o});var n=r(90394),a=r(39244),u=r(23682),s=36e5;function o(e,t){(0,u.Z)(2,arguments);var r=(0,n.Z)(t);return(0,a.Z)(e,r*s)}},39244:(e,t,r)=>{r.d(t,{Z:()=>s});var n=r(90394),a=r(34327),u=r(23682);function s(e,t){(0,u.Z)(2,arguments);var r=(0,a.Z)(e).getTime(),s=(0,n.Z)(t);return new Date(r+s)}},32182:(e,t,r)=>{r.d(t,{Z:()=>s});var n=r(90394),a=r(34327),u=r(23682);function s(e,t){(0,u.Z)(2,arguments);var r=(0,a.Z)(e),s=(0,n.Z)(t);if(isNaN(s))return new Date(NaN);if(!s)return r;var o=r.getDate(),i=new Date(r.getTime());i.setMonth(r.getMonth()+s+1,0);var l=i.getDate();return o>=l?i:(r.setFullYear(i.getFullYear(),i.getMonth(),o),r)}},33651:(e,t,r)=>{r.d(t,{Z:()=>s});var n=r(90394),a=r(79021),u=r(23682);function s(e,t){(0,u.Z)(2,arguments);var r=(0,n.Z)(t),s=7*r;return(0,a.Z)(e,s)}},27605:(e,t,r)=>{r.d(t,{Z:()=>s});var n=r(90394),a=r(32182),u=r(23682);function s(e,t){(0,u.Z)(2,arguments);var r=(0,n.Z)(t);return(0,a.Z)(e,12*r)}},4535:(e,t,r)=>{r.d(t,{Z:()=>Z});var n=r(34327);function a(e){var t=new Date(Date.UTC(e.getFullYear(),e.getMonth(),e.getDate(),e.getHours(),e.getMinutes(),e.getSeconds(),e.getMilliseconds()));return t.setUTCFullYear(e.getFullYear()),e.getTime()-t.getTime()}var u=r(59429),s=r(23682),o=864e5;function i(e,t){(0,s.Z)(2,arguments);var r=(0,u.Z)(e),n=(0,u.Z)(t),i=r.getTime()-a(r),l=n.getTime()-a(n);return Math.round((i-l)/o)}function l(e,t){var r=e.getFullYear()-t.getFullYear()||e.getMonth()-t.getMonth()||e.getDate()-t.getDate()||e.getHours()-t.getHours()||e.getMinutes()-t.getMinutes()||e.getSeconds()-t.getSeconds()||e.getMilliseconds()-t.getMilliseconds();return r<0?-1:r>0?1:r}function Z(e,t){(0,s.Z)(2,arguments);var r=(0,n.Z)(e),a=(0,n.Z)(t),u=l(r,a),o=Math.abs(i(r,a));r.setDate(r.getDate()-u*o);var Z=Number(l(r,a)===-u),g=u*(o-Z);return 0===g?0:g}},93752:(e,t,r)=>{r.d(t,{Z:()=>u});var n=r(34327),a=r(23682);function u(e){(0,a.Z)(1,arguments);var t=(0,n.Z)(e);return t.setHours(23,59,59,999),t}},1905:(e,t,r)=>{r.d(t,{Z:()=>u});var n=r(34327),a=r(23682);function u(e){(0,a.Z)(1,arguments);var t=(0,n.Z)(e),r=t.getMonth();return t.setFullYear(t.getFullYear(),r+1,0),t.setHours(23,59,59,999),t}},59281:(e,t,r)=>{r.d(t,{Z:()=>s});var n=r(34327),a=r(90394),u=r(23682);function s(e,t){(0,u.Z)(1,arguments);var r=t||{},s=r.locale,o=s&&s.options&&s.options.weekStartsOn,i=null==o?0:(0,a.Z)(o),l=null==r.weekStartsOn?i:(0,a.Z)(r.weekStartsOn);if(!(l>=0&&l<=6))throw new RangeError("weekStartsOn must be between 0 and 6 inclusively");var Z=(0,n.Z)(e),g=Z.getDay(),c=6+(g<l?-7:0)-(g-l);return Z.setDate(Z.getDate()+c),Z.setHours(23,59,59,999),Z}},70451:(e,t,r)=>{r.d(t,{Z:()=>u});var n=r(34327),a=r(23682);function u(e){(0,a.Z)(1,arguments);var t=(0,n.Z)(e),r=t.getFullYear();return t.setFullYear(r+1,0,0),t.setHours(23,59,59,999),t}},59429:(e,t,r)=>{r.d(t,{Z:()=>u});var n=r(34327),a=r(23682);function u(e){(0,a.Z)(1,arguments);var t=(0,n.Z)(e);return t.setHours(0,0,0,0),t}},13250:(e,t,r)=>{r.d(t,{Z:()=>u});var n=r(34327),a=r(23682);function u(e){(0,a.Z)(1,arguments);var t=(0,n.Z)(e);return t.setDate(1),t.setHours(0,0,0,0),t}},59401:(e,t,r)=>{r.d(t,{Z:()=>s});var n=r(34327),a=r(90394),u=r(23682);function s(e,t){(0,u.Z)(1,arguments);var r=t||{},s=r.locale,o=s&&s.options&&s.options.weekStartsOn,i=null==o?0:(0,a.Z)(o),l=null==r.weekStartsOn?i:(0,a.Z)(r.weekStartsOn);if(!(l>=0&&l<=6))throw new RangeError("weekStartsOn must be between 0 and 6 inclusively");var Z=(0,n.Z)(e),g=Z.getDay(),c=(g<l?7:0)+g-l;return Z.setDate(Z.getDate()-c),Z.setHours(0,0,0,0),Z}},69388:(e,t,r)=>{r.d(t,{Z:()=>u});var n=r(34327),a=r(23682);function u(e){(0,a.Z)(1,arguments);var t=(0,n.Z)(e),r=new Date(0);return r.setFullYear(t.getFullYear(),0,1),r.setHours(0,0,0,0),r}},34327:(e,t,r)=>{r.d(t,{Z:()=>a});var n=r(23682);function a(e){(0,n.Z)(1,arguments);var t=Object.prototype.toString.call(e);return e instanceof Date||"object"==typeof e&&"[object Date]"===t?new Date(e.getTime()):"number"==typeof e||"[object Number]"===t?new Date(e):("string"!=typeof e&&"[object String]"!==t||"undefined"==typeof console||(console.warn("Starting with v2.0.0-beta.1 date-fns doesn't accept strings as date arguments. Please use `parseISO` to parse strings. See: https://git.io/fjule"),console.warn((new Error).stack)),new Date(NaN))}}}]);